package aliyun

import (
	"encoding/json"
	"errors"
	"fmt"
	avatar20220130 "github.com/alibabacloud-go/avatar-20220130/v2/client"
	openapi "github.com/alibabacloud-go/darabonba-openapi/v2/client"
	util "github.com/alibabacloud-go/tea-utils/v2/service"
	"github.com/alibabacloud-go/tea/tea"
	"os"
	"strings"
)

// CreateClient 使用AK&SK初始化账号Client
// @return Client
// @throws Exception
func CreateClient() (_result *avatar20220130.Client, _err error) {
	// 工程代码泄露可能会导致 AccessKey 泄露，并威胁账号下所有资源的安全性。以下代码示例仅供参考。
	// 建议使用更安全的 STS 方式，更多鉴权访问方式请参见：https://help.aliyun.com/document_detail/378661.html。
	config := &openapi.Config{
		// 必填，请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_ID。
		AccessKeyId: tea.String(os.Getenv("ALIBABA_CLOUD_ACCESS_KEY_ID")),
		// 必填，请确保代码运行环境设置了环境变量 ALIBABA_CLOUD_ACCESS_KEY_SECRET。
		AccessKeySecret: tea.String(os.Getenv("ALIBABA_CLOUD_ACCESS_KEY_SECRET")),
	}

	// Endpoint 请参考 https://api.aliyun.com/product/avatar
	config.Endpoint = tea.String("avatar.cn-zhangjiakou.aliyuncs.com")
	_result = &avatar20220130.Client{}
	_result, _err = avatar20220130.NewClient(config)
	return _result, _err
}

// userId=23423 bizId=xxxxxxx
func startInstance(userId, bizId string) (*avatar20220130.StartInstanceResponseBodyData, error) {
	client, _err := CreateClient()
	if _err != nil {
		return nil, _err
	}

	tenantId := int64(9185)
	appId := "ALIPUB5748B17121450"
	startInstanceRequest := &avatar20220130.StartInstanceRequest{
		TenantId: tea.Int64(tenantId),
		App: &avatar20220130.StartInstanceRequestApp{
			AppId: tea.String(appId),
		},
		User: &avatar20220130.StartInstanceRequestUser{
			UserId: tea.String(userId),
		},
		BizId: tea.String(bizId),
	}

	_result, _err := client.StartInstance(startInstanceRequest)
	if _err != nil {
		return nil, _err
	}
	if *_result.Body.Success {
		fmt.Println(_result.Body.Data)
		return _result.Body.Data, nil
	}
	return nil, errors.New(*_result.Body.Message)
}

func _main(args []*string) (_err error) {
	client, _err := CreateClient()
	if _err != nil {
		return _err
	}

	sendMessageRequest := &avatar20220130.SendMessageRequest{
		SessionId: tea.String("your_value"),
		TenantId:  tea.Int64(1),
		Feedback:  tea.Bool(false),
	}
	tryErr := func() (_e error) {
		defer func() {
			if r := tea.Recover(recover()); r != nil {
				_e = r
			}
		}()
		// 复制代码运行请自行打印 API 的返回值
		_, _err = client.SendMessageWithOptions(sendMessageRequest, &util.RuntimeOptions{})
		if _err != nil {
			return _err
		}

		return nil
	}()

	if tryErr != nil {
		var error = &tea.SDKError{}
		if _t, ok := tryErr.(*tea.SDKError); ok {
			error = _t
		} else {
			error.Message = tea.String(tryErr.Error())
		}
		// 此处仅做打印展示，请谨慎对待异常处理，在工程项目中切勿直接忽略异常。
		// 错误 message
		fmt.Println(tea.StringValue(error.Message))
		// 诊断地址
		var data interface{}
		d := json.NewDecoder(strings.NewReader(tea.StringValue(error.Data)))
		d.Decode(&data)
		if m, ok := data.(map[string]interface{}); ok {
			recommend, _ := m["Recommend"]
			fmt.Println(recommend)
		}
		_, _err = util.AssertAsString(error.Message)
		if _err != nil {
			return _err
		}
	}
	return _err
}

//func main() {
//	err := _main(tea.StringSlice(os.Args[1:]))
//	if err != nil {
//		panic(err)
//	}
//}
